@@ -71,8 +71,18 @@ class BillText(AbstractText):
         ID = 'id'
         TITLE = 'title'
         BODY = 'body'
-        SUPPL = 'suppl'
+        SUPPLEMENT = 'supplement'
         REASON = 'reason'
+        ALIASES = 'aliases'
+        TAGS = 'tags'
+        CATEGORY = 'category'
+        STATUS = 'status'
+        SUBMITTED_DATE = 'submitted_date'
+        LAST_UPDATED_DATE = 'last_updated_date'
+        GROUPS = 'groups'
+        MINISTRIES = 'ministries'
+        SUBMITTED_DIET = 'submitted_diet'
+        BELONGED_TO_DIETS = 'belonged_to_diets'
 
 
 class MinutesText(AbstractText):
